# CHANGELOG



## v0.1.2 (2023-09-19)

### Fix

* fix: cd test install package name ([`d5be5ff`](https://github.com/MediWizards/revonto/commit/d5be5ff03c325290f595406ec6b6d27ccb884e2c))

### Unknown

* [no_ci] change example comments ([`0359530`](https://github.com/MediWizards/revonto/commit/0359530f1441e8d978074a2eb86b06ca1d0586fe))

* Update README.md ([`8574810`](https://github.com/MediWizards/revonto/commit/8574810a6db07b0eb1663f3a8241bb52d6336f19))

* Add examples, feat: match_annotataions_to_godag (#9), add coverage to ci

* add cancer/inflammation example

* feat: add match_annotations_to_godag

* fix: add test_match_annotations_to_godag

* lint

* fix: filepath in example

* lint

* fix check_manifest ignore

* split optional dependancies

* add diff coverage

* fix: missing install diff-cover

* addd pytest sugar and pytest cov

* fix: env for pytest in ci

* fix: coverage now works

* add coveralls

* add coverage badge ([`1d03d4b`](https://github.com/MediWizards/revonto/commit/1d03d4bcb6853a2985b72517002b3a1171d50104))

* split create release and deploy (#8) ([`73f067a`](https://github.com/MediWizards/revonto/commit/73f067a14e2e5ca1d6ae777684da1df7477de485))


## v0.1.1 (2023-09-19)

### Fix

* fix: from ci remove on push: main (#6) ([`0779372`](https://github.com/MediWizards/revonto/commit/077937214e8ea50776b84f4e8f8065612d9fd6a5))

### Unknown

* reverse to pat, add check for semantic-release (#7) ([`61d55cd`](https://github.com/MediWizards/revonto/commit/61d55cd17954047a4f4557538fee64be2ba8f80b))

* separate ci cd and fix semantic-version-release (#5)

* merge ci-cd

* add isort, remove mypy

* add semantic versioning

* lint

* bug: remove editorconfig

* bug: remove editorconfig

* add build to cd

* add admin token

* fix: python-semantic-release ([`573c7a7`](https://github.com/MediWizards/revonto/commit/573c7a7d3b37ceab7aa62c8a2738a8103a812ffb))


## v0.1.0 (2023-09-18)

### Feature

* feat: results intersection ([`200f3a8`](https://github.com/MediWizards/revonto/commit/200f3a8def4071e289026c3178c531a492740a1f))

### Fix

* fix: ci naming ([`0daea9e`](https://github.com/MediWizards/revonto/commit/0daea9e8b7cdc36269d84597eab4ea4fabb408f8))

### Unknown

* add admin token (#4)

* merge ci-cd

* add isort, remove mypy

* add semantic versioning

* lint

* bug: remove editorconfig

* bug: remove editorconfig

* add build to cd

* add admin token ([`d9669cc`](https://github.com/MediWizards/revonto/commit/d9669cc7a35ed29085fd97b8342ae03ec94c7e23))

* add deploy to cd (#3)

* merge ci-cd

* add isort, remove mypy

* add semantic versioning

* lint

* bug: remove editorconfig

* bug: remove editorconfig

* add build to cd ([`2e1010f`](https://github.com/MediWizards/revonto/commit/2e1010ffc376fe5a6da8952c67acfcda71052615))

* Merge branch &#39;main&#39; of https://github.com/MediWizards/revonto ([`6cc8511`](https://github.com/MediWizards/revonto/commit/6cc85110bea0ba10a8b01f4daac66db5895a9b92))

* remove editorconfig (#2)

* merge ci-cd

* add isort, remove mypy

* add semantic versioning

* lint

* bug: remove editorconfig

* bug: remove editorconfig ([`8651263`](https://github.com/MediWizards/revonto/commit/8651263ef28d13ce9989d2fd4122b908e5de251c))

* merge ci-cd (#1)

* merge ci-cd

* add isort, remove mypy

* add semantic versioning

* lint ([`bf26bb6`](https://github.com/MediWizards/revonto/commit/bf26bb62d956be0f6fab42fd0c363f0d236be114))

* add multiple testing ([`94efabc`](https://github.com/MediWizards/revonto/commit/94efabc58fad2887b23279de6ed2c6e24edf51ae))

* change annotations from dict to set ([`fe22733`](https://github.com/MediWizards/revonto/commit/fe22733e4a7ffaf46a20e804ad85c4fe4bf42152))

* remove version from init ([`98b9ab0`](https://github.com/MediWizards/revonto/commit/98b9ab0d3d69e262cb5e8569e9aca59e8292b2f6))

* less strict mypy ci ([`bba2d6b`](https://github.com/MediWizards/revonto/commit/bba2d6b218597a659069955cfce4864f742ca6f4))

* formatting, linting ([`2923e4b`](https://github.com/MediWizards/revonto/commit/2923e4bf1f422a609a1f3de43f77a9c3da71f7f5))

* annotations shape, custom dict, set operations ([`7fb8021`](https://github.com/MediWizards/revonto/commit/7fb802106ad15db8c8836a02537efc581818cb79))

* update ci-cd ([`88490f3`](https://github.com/MediWizards/revonto/commit/88490f3ef09b1fd45f97553c5fdef99471c225f8))

* reverse lookup study ([`68e68d4`](https://github.com/MediWizards/revonto/commit/68e68d44480c240d64e09e1371348ff249e0665c))

* add function to associations, change to goterm key ([`375c671`](https://github.com/MediWizards/revonto/commit/375c67149616e0ed59ce11caaf40acfb633e1716))

* add associations ([`4ca02d0`](https://github.com/MediWizards/revonto/commit/4ca02d063bbafb34112f6c4e393669ddeba46ceb))

* cleanup and more some multiple test code ([`e83ae4c`](https://github.com/MediWizards/revonto/commit/e83ae4cb5b2699f6641431032e8e38b8f32d08ed))

* add pval calc ([`f65654a`](https://github.com/MediWizards/revonto/commit/f65654a10453b3832669627a141c596ae5b89c53))

* add associations framework ([`dc5c8d6`](https://github.com/MediWizards/revonto/commit/dc5c8d6c6ee9f2ab656a992381f1d3cc3aa4da12))

* update readme ([`cf4023a`](https://github.com/MediWizards/revonto/commit/cf4023a06f3f6ff8e0f87ad3b7db84833c478d79))

* update github actions matrix ([`63e2694`](https://github.com/MediWizards/revonto/commit/63e2694fd3419619e9d033bcde658953fef00d5c))

* fix min python version 3.9 ([`c82448e`](https://github.com/MediWizards/revonto/commit/c82448e4913556f2b17285afca99d0f0bb6eb213))

* min python version is 3.9 ([`1ee7077`](https://github.com/MediWizards/revonto/commit/1ee707767055328b07b7e4cb8ec90227aaf22d1d))

* typehints ([`c0d0e9d`](https://github.com/MediWizards/revonto/commit/c0d0e9d91777637d6f4a956b8f7d7bbe7d049d04))

* obo parser (ontology.py) ([`46c5f19`](https://github.com/MediWizards/revonto/commit/46c5f198b4e384557ef791638de3582a0d1bf5ec))

* create files, .toml ([`d7a6a91`](https://github.com/MediWizards/revonto/commit/d7a6a91bb4a30a6c96e6cf5a95de27c20edba2d8))

* change to revonto ([`265037e`](https://github.com/MediWizards/revonto/commit/265037efd33f10caef85d7ec8855142b533bd45a))

* remove python 3.6 ([`c00766e`](https://github.com/MediWizards/revonto/commit/c00766ee6da85d054a0ae169c9abf1cad1255931))

* change to GPLv3 ([`20bd28d`](https://github.com/MediWizards/revonto/commit/20bd28d4769be7cec8d9ec8c010a13d7e5cd1d85))

* Initial commit ([`7cf74eb`](https://github.com/MediWizards/revonto/commit/7cf74eb0b8844fbd68b019497697144b6d2b28d6))
